package net.knarcraft.ffmpegconverter.converter.module.output;

import net.knarcraft.ffmpegconverter.container.FFMpegCommand;
import net.knarcraft.ffmpegconverter.converter.module.ConverterModule;
import net.knarcraft.ffmpegconverter.streams.StreamObject;
import org.jetbrains.annotations.NotNull;

import java.util.List;

/**
 * A module for setting the language of some streams
 *
 * @param <K> <p>The type of stream to set language for</p>
 */
public class SetStreamLanguageModule<K extends StreamObject> implements ConverterModule {

    private final List<K> streams;

    /**
     * Instantiates a new set stream language module
     *
     * @param streams <p>The streams to set language for</p>
     */
    public SetStreamLanguageModule(@NotNull List<K> streams) {
        this.streams = streams;
    }

    @Override
    public void addArguments(@NotNull FFMpegCommand command) {
        for (StreamObject stream : this.streams) {
            if (!stream.getLanguage().equalsIgnoreCase("und") && !stream.getLanguage().isBlank()) {
                command.addOutputFileOption(String.format("-metadata:s:%s:%d", stream.streamTypeCharacter(),
                        stream.getOutputIndex()), String.format("language=%s", stream.getLanguage()));
            }
        }
    }

}
