package net.knarcraft.ffmpegconverter.converter.sorter;

import net.knarcraft.ffmpegconverter.streams.StreamObject;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * A sorter that puts the stream with the given relative index first, without changing order of other items
 *
 * @param <K> <p>The type of stream to sort</p>
 */
public class ForcedFirstSorter<K extends StreamObject> extends AbstractSorter<K> {

    private final int forcedIndex;

    /**
     * Instantiates a new forced first sorter
     *
     * @param forcedIndex <p>The relative index of the stream to set as the first item</p>
     */
    public ForcedFirstSorter(int forcedIndex) {
        this.forcedIndex = forcedIndex;
    }

    @Override
    public @NotNull List<K> sort(@NotNull List<K> input) {
        if (input.isEmpty()) {
            return input;
        }

        int listIndex = 0;
        for (int i = 0; i < input.size(); i++) {
            if (input.get(i).getRelativeIndex() == forcedIndex) {
                listIndex = i;
                break;
            }
        }
        List<K> output = new ArrayList<>(input);
        K first = output.remove(listIndex);
        output.add(0, first);
        return output;
    }

}
