package net.knarcraft.ffmpegconverter.utility;

import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * A class which helps with operations on strings
 */
final class StringUtil {

    private StringUtil() {

    }

    /**
     * Finds all substrings between two substrings in a string
     *
     * @param input <p>The string containing the substrings.</p>
     * @param start <p>The substring before the wanted substring.</p>
     * @param end   <p>The substring after the wanted substring.</p>
     * @return <p>A list of all occurrences of the substring.</p>
     */
    public static @NotNull List<String> stringBetween(@NotNull String input, @NotNull String start,
                                                      @NotNull String end) {
        List<String> output = new ArrayList<>();
        String inputString = input;
        while (true) {
            int startPosition = inputString.indexOf(start) + start.length();
            //Return if the string is not found
            if (!inputString.contains(start) || inputString.indexOf(end, startPosition) < startPosition) {
                return output;
            }
            int endPosition = inputString.indexOf(end, startPosition);
            //Get the string between the start and end string
            output.add(inputString.substring(startPosition, endPosition).trim());
            inputString = inputString.substring(endPosition + end.length());
        }
    }

}
